@@ -3,8 +3,8 @@ package Image::Grab;
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD);
 
-# $Id: Grab.pm,v 1.6 2002/01/19 21:14:01 mah Exp $
-$VERSION = '1.4.2';
+# $Id: Grab.pm,v 1.3 2000/05/25 05:53:33 mah Exp $
+$VERSION = '1.1';
 
 use Carp;
 use Config;
@@ -37,12 +37,10 @@ my %fields = (
 	      url        => undef,
 	      search_url => undef,
 	      debug      => undef,
-	      do_posix   => ($Config{patchlevel} && $Config{patchlevel} >= 5 and
-			     $Config{baserev} && $Config{baserev}    >= 5) ? 1 : undef,
+	      do_posix   => ($Config{patchlevel} >= 5 and 
+			     $Config{baserev}    >= 5) ? 1 : undef,
 	     );
 
-sub DESTROY {}
-
 sub new {
   my $that  = shift;
   my $class = ref($that) || $that;
@@ -63,7 +61,6 @@ sub new {
 
   bless ($self, $class);
   $self->ua(new Image::Grab::RequestAgent);
-  $self->{have_DigestMD5} = eval {require Digest::MD5};
   $self->{have_MD5} = eval {require MD5;};
   $self->{have_magick} = eval {require Image::Magick;};
   return $self;
@@ -136,18 +133,18 @@ sub getAllURLs {
   if($count == $times && !$req->is_success){
     return undef;
   }
-
+  return undef unless $req->content_type eq 'text/html';
+  
   # Get the base url
   my $base_url = $req->base;
-
+  
   # Get the img tags out of the document.
   my $parser = new HTML::TreeBuilder;
   $parser->parse($req->content);
   $parser->eof;
-  foreach (@{$parser->extract_links(qw(img td body))}) {
+  foreach (@{$parser->extract_links(qw(img))}) {
     push @link, URI::URL::url($$_[0])->abs($base_url)->as_string;
-  }
-  $parser->delete;
+  }  
 
   return @link;
 }
@@ -172,7 +169,7 @@ sub expand_url {
   my @link;
   my @now;
 
-  # Expand any POSIX time escapes
+  # Expand any POSIX time excapes
   @now = localtime;
 
   if(defined $self->url) {
@@ -180,24 +177,22 @@ sub expand_url {
       if defined $self->do_posix;
     return $self->url;
   }
-  $self->regexp(strftime($self->regexp, @now))
+  $self->regexp(strftime($self->regexp, @now)) 
     if defined $self->regexp and defined $self->do_posix;
 
   @link = $self->getAllURLs($times);
-  return undef if !@link;
+  return undef if !defined @link;
 
   # if this is a relative position tag...
   if($self->regexp || $self->index) {
     my (@match, $re);
 
-    $self->refer($self->search_url);
-    # set index to match first image
+    # set index to match fist image
     $self->index(0) if !defined $self->index;
     $re = $self->regexp || '.';
     @match = grep {defined && /$re/} @link;
-    # Return the nth
-    return $match[$self->index]
-      if @match;
+    # Return the nth 
+    return $match[$self->index];
   }
 
   # only if we fail.
@@ -227,17 +222,10 @@ sub loadCookieJar {
 sub grab {
   my $self = shift;
   my $times = 1;
-
   if(ref($self)) {
-    if(my $c = shift) {
-      $times = $c;
-    }
+    $times ||= shift;
   } else {
-    if($self eq __PACKAGE__) {
-      $self = Image::Grab->new(@_);
-    } else {
-      $self = Image::Grab->new(lc $self, @_);
-    }
+    $self = Image::Grab->new(@_)
   }
   my $req;
   my $count;
@@ -247,14 +235,14 @@ sub grab {
   $self->loadCookieJar;
 
   # need to find image on page?
-  my $url = $self->expand_url($times);
+  $self->url($self->expand_url($times));
 
   # make sure we have a url
-  croak "Couldn't determine an absolute URL!\n" unless defined $url;
-  carp "Fetching URL: ", $url if $self->debug;
+  croak "Couldn't determine an absolute URL!\n" unless defined $self->url;
+  carp "Fetching URL: ", $self->url if $self->debug;
 
   # Set it up
-  $req = new HTTP::Request 'GET', $url;
+  $req = new HTTP::Request 'GET', $self->url;
   $req->push_header('Referer', $self->refer) if defined $self->refer;
   if($self->cookiejar){
     $self->cookiejar->add_cookie_header($req);
@@ -265,8 +253,6 @@ sub grab {
   do{
     $count++;
     $rc = $self->ua->request($req);
-    carp "Got: ", $rc->content
-      if $self->debug;
   } while($count <= $times and not $rc->is_success);
 
   # Did we fail?
@@ -277,13 +263,8 @@ sub grab {
   # save what we got
   $self->image($rc->content);
   $self->date($rc->last_modified);
-
-  if($self->{have_DigestMD5}) {
-    $self->md5(Digest::MD5::md5_hex($self->image));
-  } elsif ($self->{have_MD5}) {
-    $self->md5(MD5->hexhash($self->image));
-  }
-
+  $self->md5(MD5->hexhash($self->image))  # This is how we set it
+    if $self->{have_MD5};	          # initially.
 
   $self->type($rc->content_type);
 
